LanguageType

Enum LanguageType 

pub enum LanguageType {
    Living,
    Extinct,
    Ancient,
    Historic,
    Constructed,
    Special,
}
The five language types defined in ISO 639-3 for individual languages.

Variants



Living

Living languages

A language is listed as living when there are people still living who learned it as a first language. This part of ISO 639 also includes identifiers for languages that are no longer living.



Extinct

Extinct languages

A language is listed as extinct if it has gone extinct in recent times. (e.g. in the last few centuries). The criteria for identifying distinct languages in these case are based on intelligibility (as defined for individual languages).



Ancient

Ancient languages

A language is listed as ancient if it went extinct in ancient times (e.g. more than a millennium ago). Identifiers are assigned to ancient languages which have a distinct literature and are treated distinctly by the scholarly community. It would be ideal to be able to assign identifiers to ancient languages on the basis of intelligibility, but ancient records rarely contain enough information to make this possible. In order to qualify for inclusion in ISO 639-3, the language must have an attested literature or be well-documented as a language known to have been spoken by some particular community at some point in history; it may not be a reconstructed language inferred from historical-comparative analysis.



Historic

Historic languages

A language is listed as historic when it is considered to be distinct from any modern languages that are descended from it: for instance, Old English and Middle English. In these cases, the language did not become extinct; rather, it changed into a different language over time. Here, too, the criterion is that the language have a literature that is treated distinctly by the scholarly community.



Constructed

Constructed languages

This part of ISO 639 also includes identifiers that denote constructed (or artificial) languages. In order to qualify for inclusion the language must have a literature and it must be designed for the purpose of human communication. It must be a complete language, and be in use for human communication by some community long enough to be passed to a second generation of users. Specifically excluded are reconstructed languages and computer programming languages.



Special

Special and Reserved

Four codes are set aside in ISO 639-2 and ISO 639-3 for cases where none of the specific codes are appropriate. These are intended primarily for applications like databases where an ISO code is required regardless of whether one exists.

In addition, 520 codes in the range qaa–qtz are ‘reserved for local use’.